<?php
/**
 * zibber functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package zibber
 */

if ( ! function_exists( 'zibber_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function zibber_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on zibber, use a find and replace
		 * to change 'zibber' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'zibber', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'main-menu' => esc_html__( 'Main Menu', 'zibber' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'zibber' ),
			'service-menu' => esc_html__( 'Service Menu', 'zibber' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'zibber_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		//Enable custom header
		add_theme_support('custom-header');

        // enable woocommerce
        add_theme_support('woocommerce');

        remove_theme_support( 'widgets-block-editor' );
		


		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/**
		 * Enable suporrt for Post Formats
		 *
		 * see: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'image',
			'audio',
			'video',
			'gallery',
			'quote',
		) );

		// Add theme support for selective refresh for widgets.
		//add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );


		add_image_size( 'zibber-pro-thumb', 500, 550, array('center','center') );
		add_image_size( 'zibber-post-thumb', 400, 450, array('center','center') );
	}
endif;
add_action( 'after_setup_theme', 'zibber_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function zibber_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'zibber_content_width', 640 );
}
add_action( 'after_setup_theme', 'zibber_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function zibber_widgets_init() {

	$footer_style_2_switch = get_theme_mod('footer_style_2_switch', true );
	$footer_style_3_switch = get_theme_mod('footer_style_3_switch', true );
	$footer_style_4_switch = get_theme_mod('footer_style_4_switch', true );

	/**
	* blog sidebar
	*/
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'zibber' ),
		'id'            => 'blog-sidebar',
		'before_widget' => '<div id="%1$s" class="sidebar__widget mb-50 %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="sidebar__widget-title mb-50"><h4>',
		'after_title'   => '</h4></div>',
	) );

    register_sidebar(array(
        'name' => esc_html__('Product Sidebar', 'zibber'),
        'id' => 'product-sidebar',
        'before_widget' => '<div id="%1$s" class="product-widgets side-cat %2$s mb-45">',
        'after_widget' => '</div>',
        'before_title' => '<h6 class="product-widget-title">',
        'after_title' => '</h6>',

    ));


	$footer_widgets = get_theme_mod('footer_widget_number', 4);


	for( $num=1; $num <= $footer_widgets; $num++ ) {
		register_sidebar( array(
			'name'          => esc_html__( 'Footer '. $num, 'zibber'),
			'id'            => 'footer-'. $num,
			'description'   => esc_html__( 'Footer '. $num, 'zibber' ),
			'before_widget' => '<div id="%1$s" class="footer__widget footer__widget-default mb-50 %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="footer__widget-title text-white"><h4>',
			'after_title'   => '</h4></div>',
		) );			
	}


	// footer 2
	if ( $footer_style_2_switch ) {
		for( $num=1; $num <= $footer_widgets; $num++ ) {

			register_sidebar( array(
				'name'          => esc_html__( 'Footer Style 2: '. $num, 'zibber'),
				'id'            => 'footer-2-'. $num,
				'description'   => esc_html__( 'Footer Style 2: '. $num, 'zibber' ),
				'before_widget' => '<div id="%1$s" class="footer__widget mb-50 %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="footer__widget-title"><h4>',
				'after_title'   => '</h4></div>',
			) );			
		}
	}

	// footer 3
	if ( $footer_style_3_switch ) {
		for( $num=1; $num <= $footer_widgets; $num++ ) {
			register_sidebar( array(
				'name'          => esc_html__(  'Footer Style 3: '. $num, 'zibber'),
				'id'            => 'footer-3-'. $num,
				'description'   => esc_html__( 'Footer Style 3: '. $num, 'zibber' ),
				'before_widget' => '<div id="%1$s" class="footer__widget mb-50 %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="footer__widget-title"><h4>',
				'after_title'   => '</h4></div>',
			) );			
		}
	}		

	// footer 4
	if ( $footer_style_4_switch ) {
		for( $num=1; $num <= $footer_widgets; $num++ ) {
			register_sidebar( array(
				'name'          => esc_html__(  'Footer Style 4: '. $num, 'zibber'),
				'id'            => 'footer-4-'. $num,
				'description'   => esc_html__( 'Footer Style 4: '. $num, 'zibber' ),
				'before_widget' => '<div id="%1$s" class="footer__widget mb-50 %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<div class="footer__widget-title"><h4>',
				'after_title'   => '</h4></div>',
			) );			
		}
	}	

	/**
	* Service Widget
	*/
	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Service Sidebar', 'zibber' ),
			'id' 			=> 'services-sidebar',
			'description' 	=> esc_html__( 'Widgets in this area will be shown on Service Details Sidebar.', 'zibber' ),
			'before_widget' => '<div class="services__widget grey-bg-18 mb-40 %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<div class="services__widget-title"><h4>',
			'after_title' 	=> '</h4></div>',
		)
	);	

	/**
	* Portfolio Widget
	*/
	register_sidebar(
		array(
			'name' 			=> esc_html__( 'Portfolio Sidebar', 'zibber' ),
			'id' 			=> 'portfolio-sidebar',
			'description' 	=> esc_html__( 'Widgets in this area will be shown on Portfolio Details Sidebar.', 'zibber' ),
			'before_title' 	=> '<div class="widget-title-box mb-30"><h3 class="widget-title">',
			'after_title' 	=> '</h3></div>',
			'before_widget' => '<div class="service-widget sidebar-wrap widget mb-50 %2$s">',
			'after_widget' 	=> '</div>',
		)
	);	




}
add_action( 'widgets_init', 'zibber_widgets_init' );

/**
 * Enqueue scripts and styles.
 */

define('zibber_THEME_DIR', get_template_directory());
define('zibber_THEME_URI', get_template_directory_uri());
define('ZIBBER_THEME_CSS_DIR', zibber_THEME_URI . '/assets/css/');
define('ZIBBER_THEME_JS_DIR', zibber_THEME_URI . '/assets/js/');
define('ZIBBER_THEME_INC', zibber_THEME_DIR . '/inc/');

/** 
 * zibber_scripts description
 * @return [type] [description]
 */
function zibber_scripts() {
	/**
	* all css files
	*/
	wp_enqueue_style( 'zibber-fonts', zibber_fonts_url(), array(), '1.0.0' );
    if( is_rtl() ){
        wp_enqueue_style( 'bootstrap-rtl', ZIBBER_THEME_CSS_DIR .'bootstrap.rtl.min.css', array() );
    }else{
        wp_enqueue_style( 'bootstrap', ZIBBER_THEME_CSS_DIR .'bootstrap.min.css', array() );
    }
	wp_enqueue_style( 'preloader', ZIBBER_THEME_CSS_DIR.'preloader.css', array() );
	wp_enqueue_style( 'slick', ZIBBER_THEME_CSS_DIR.'slick.css', array() );
	wp_enqueue_style( 'meanmenu', ZIBBER_THEME_CSS_DIR.'meanmenu.css', array() );
	wp_enqueue_style( 'owl-carousel', ZIBBER_THEME_CSS_DIR.'owl.carousel.min.css', array() );
	wp_enqueue_style( 'animate', ZIBBER_THEME_CSS_DIR.'animate.min.css', array() );
	wp_enqueue_style( 'jquery-fancybox', ZIBBER_THEME_CSS_DIR.'jquery.fancybox.min.css', array() );
	wp_enqueue_style( 'fontawesome-pro', ZIBBER_THEME_CSS_DIR.'fontAwesome5Pro.css', array() );
	wp_enqueue_style( 'elegantfont', ZIBBER_THEME_CSS_DIR.'elegantFont.css', array() );
	wp_enqueue_style( 'zibber-default', ZIBBER_THEME_CSS_DIR.'default.css', array() );
	wp_enqueue_style( 'zibber-shop', ZIBBER_THEME_CSS_DIR.'shop.css', array() );
	wp_enqueue_style( 'zibber-core', ZIBBER_THEME_CSS_DIR.'zibber-core.css', array() );
	wp_enqueue_style( 'zibber-unit', ZIBBER_THEME_CSS_DIR.'zibber-unit.css', array() );
	wp_enqueue_style( 'zibber-style', get_stylesheet_uri() );
	wp_enqueue_style( 'zibber-responsive', ZIBBER_THEME_CSS_DIR.'responsive.css', array() );



	// all js
	wp_enqueue_script( 'waypoints', ZIBBER_THEME_JS_DIR.'waypoints.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'bootstrap-bundle', ZIBBER_THEME_JS_DIR.'bootstrap.bundle.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'jquery-meanmenu', ZIBBER_THEME_JS_DIR.'jquery.meanmenu.js', array('jquery'), '', true );
	wp_enqueue_script( 'slick', ZIBBER_THEME_JS_DIR.'slick.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'jquery-fancybox', ZIBBER_THEME_JS_DIR.'jquery.fancybox.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'jquery-counterup', ZIBBER_THEME_JS_DIR.'jquery.counterup.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'isotope-pkgd', ZIBBER_THEME_JS_DIR.'isotope.pkgd.min.js', array('imagesloaded'), false, true );
	wp_enqueue_script( 'owl-carousel', ZIBBER_THEME_JS_DIR.'owl.carousel.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'parallax', ZIBBER_THEME_JS_DIR.'parallax.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'wow', ZIBBER_THEME_JS_DIR.'wow.min.js', array('jquery'), false, true );
	wp_enqueue_script( 'zibber-main', ZIBBER_THEME_JS_DIR.'main.js', array('jquery'), false, true );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 'zibber_scripts' );

/*
Register Fonts
*/

function zibber_fonts_url() {
    $font_url = '';
    $zibber_fonts_url = '';
	$zibber_fonts_url = get_theme_mod( 'zibber_fonts_url','family=Frank+Ruhl+Libre:wght@300;400;500;700&family=Lato:wght@300;400;700&display=swap');

    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'zibber' ) ) {
        $font_url = 'https://fonts.googleapis.com/css2?family=Frank+Ruhl+Libre:wght@300;400;500;700&family=Lato:wght@300;400;700&display=swap';
    }
    return $font_url;
}


// wp_body_open
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
            do_action( 'wp_body_open' );
    }
}



/**
 * Implement the Custom Header feature.
 */
require ZIBBER_THEME_INC . 'custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require ZIBBER_THEME_INC . 'template-functions.php';

/**
 * Custom template helper function for this theme.
 */
require ZIBBER_THEME_INC . 'template-helper.php';

if (!defined('ZIBBER_WOOCOMMERCE_ACTIVED')) {
    define('ZIBBER_WOOCOMMERCE_ACTIVED', in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))));
}

define('ZIBBER_WISHLIST_ACTIVED', in_array('yith-woocommerce-wishlist/init.php', apply_filters('active_plugins', get_option('active_plugins'))));

define('ZIBBER_COMPARE_ACTIVED', in_array('yith-woocommerce-compare/init.php', apply_filters('active_plugins', get_option('active_plugins'))));

define('ZIBBER_QUICK_VIEW_ACTIVED', in_array('yith-woocommerce-quick-view/init.php', apply_filters('active_plugins', get_option('active_plugins'))));

if (ZIBBER_WOOCOMMERCE_ACTIVED) {
    require_once ZIBBER_THEME_INC . 'zibber-woocommerce.php';
}

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require ZIBBER_THEME_INC . 'jetpack.php';
}

/**
* include zibber functions file
*/
require_once ZIBBER_THEME_INC . 'class-breadcrumb.php';
require_once ZIBBER_THEME_INC . 'class-navwalker.php';
require_once ZIBBER_THEME_INC . 'class-customizer.php';
require_once ZIBBER_THEME_INC . 'customizer_data.php';
require_once ZIBBER_THEME_INC . 'class-tgm-plugin-activation.php';
require_once ZIBBER_THEME_INC . 'add_plugin.php';



/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function zibber_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'zibber_pingback_header' );


/**
*
* comment section
*
*/
add_filter('comment_form_default_fields', 'zibber_comment_form_default_fields_func');

function zibber_comment_form_default_fields_func($default){

	$default['author'] = '<div class="row">
    <div class="col-xl-6 col-md-6">
    	<div class="post-input">
        	<input type="text" name="author" placeholder="'.esc_attr__('Your Name','zibber').'">
        </div>
    </div>';
	$default['email'] = '<div class="col-xl-6 col-md-6">
		<div class="post-input">
        <input type="text" name="email" placeholder="'.esc_attr__('Your Email','zibber').'">
    	</div>
    </div>';
	// $default['url'] = '';
	$defaults['comment_field'] = '';

	$default['url'] = '<div class="col-xl-12">
		<div class="post-input">
        <input type="text" name="url" placeholder="'.esc_attr__('Website','zibber').'">
    	</div>
    </div>';
	/* $default['clients_commnet'] = '<div class="col-xl-12">
	<div class="contacts-message">
	<label>'.esc_html__('Comments *','zibber').'</label>
     <textarea id="comment" name="comment" cols="30" rows="10"></textarea>
    </div>'; */
	return $default;
}

add_action( 'comment_form_top', 'zibber_add_comments_textarea' );
function zibber_add_comments_textarea()
{
	if( !is_user_logged_in() ){
    echo '<div class="row"><div class="col-xl-12"><div class="post-input pro-details-none"><textarea id="comment" name="comment" cols="60" rows="6" placeholder="'.esc_attr__('Write your comment here...','zibber').'" aria-required="true"></textarea></div></div></div>';
	}
}

add_filter('comment_form_defaults', 'zibber_comment_form_defaults_func');

function zibber_comment_form_defaults_func($info){
	if( !is_user_logged_in() ){
		$info['comment_field'] = '';
		$info['submit_field'] = '%1$s %2$s</div>';
	}else {
		$info['comment_field'] = '<div class="post-input"><textarea id="comment" name="comment" cols="30" rows="10" placeholder="'.esc_attr__('Comments *','zibber').'"></textarea>';
        $info['submit_field'] = '%1$s %2$s</div>';
	}


	$info['submit_button'] = '<div class="col-xl-12"><button class="z-btn" type="submit">'.esc_html__('Post Comment','zibber').' </button></div>';

	$info['title_reply_before'] = '<div class="post-comments-title">
                                        <h2>';
	$info['title_reply_after'] = '</h2></div>';
	$info['comment_notes_before'] = '';

	return $info;
}

if( !function_exists('zibber_comment') ) {
	function zibber_comment($comment, $args, $depth) {
		$GLOBAL['comment'] = $comment;
		extract($args, EXTR_SKIP);
		$args['reply_text'] = '<i class="arrow_back"></i> Reply';
		$replayClass = 'comment-depth-' . esc_attr($depth);
		?>
			<li id="comment-<?php comment_ID(); ?>">
				<div class="comments-box">
					<div class="comments-avatar">
						<?php print get_avatar($comment, 102, null, null, array('class'=> array())); ?>
					</div>
					<div class="comments-text">
						<div class="avatar-name">
							<h5><?php print get_comment_author_link(); ?></h5>
							<span><?php comment_time( get_option('date_format') ); ?></span>
						</div>
						<?php comment_text(); ?>
						<?php comment_reply_link( array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth'] ))); ?>
					</div>
				</div>
		<?php
	}
}



/**
* shortcode supports for removing extra p, spance etc
*
*/
add_filter( 'the_content', 'zibber_shortcode_extra_content_remove' );
/**
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 *
 * @since 1.0.0
 *
 * @param string $content  String of HTML content.
 * @return string $content Amended string of HTML content.
 */
function zibber_shortcode_extra_content_remove( $content ) {

    $array = array(
        '<p>['    => '[',
        ']</p>'   => ']',
        ']<br />' => ']'
    );
    return strtr( $content, $array );

}


// zibber_search_filter_form
if( !function_exists('zibber_search_filter_form')) {
  function zibber_search_filter_form( $form ) {
    
    $form = sprintf( 
    	'<div class="sidebar__widget-content"><div class="search"><form class="sidebar-widget-form" action="%s" method="get">
      	<input type="text" value="%s" required name="s" placeholder="%s">
      	<button type="submit"> <i class="far fa-search"></i>  </button>
		</form></div></div>',
		esc_url( home_url('/') ),
		esc_attr( get_search_query() ),
		esc_html__('Search','zibber')
	);

    return $form;
  }
  add_filter( 'get_search_form','zibber_search_filter_form');
}

add_action('admin_enqueue_scripts', 'zibber_admin_custom_scripts');

function zibber_admin_custom_scripts() {
	wp_enqueue_media();
	wp_register_script('zibber-admin-custom', get_template_directory_uri().'/inc/js/admin_custom.js', array('jquery'), '', true);
	wp_enqueue_script('zibber-admin-custom');
}

// enable_rtl
function zibber_enable_rtl()
{
    if (get_theme_mod('rtl_switch', false)) {
        return ' dir="rtl" ';
    } else {
        return '';
    }
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328973&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        