<?php

/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package zibber
 */

/**
 *
 * zibber header
 */

function zibber_check_header()
{
    $zibber_header_style = function_exists('get_field') ? get_field('header_style') : NULL;
    $zibber_default_header_style = get_theme_mod('choose_default_header', 'header-style-1');

    if ($zibber_header_style == 'header-style-1') {
        zibber_header_style_1();
    } elseif ($zibber_header_style == 'header-style-2') {
        zibber_header_style_2();
    } elseif ($zibber_header_style == 'header-style-3') {
        zibber_header_style_3();
    } elseif ($zibber_header_style == 'header-style-4') {
        zibber_header_style_4();
    } elseif ($zibber_header_style == 'header-style-5') {
        zibber_header_style_5();
    } elseif ($zibber_header_style == 'header-style-6') {
        zibber_header_style_6();
    } else {

        /** default header style **/
        if ($zibber_default_header_style == 'header-style-2') {
            zibber_header_style_2();
        } elseif ($zibber_default_header_style == 'header-style-3') {
            zibber_header_style_3();
        } elseif ($zibber_default_header_style == 'header-style-4') {
            zibber_header_style_4();
        } elseif ($zibber_default_header_style == 'header-style-5') {
            zibber_header_style_5();
        } elseif ($zibber_default_header_style == 'header-style-6') {
            zibber_header_style_6();
        } else {
            zibber_header_style_1();
        }
    }
}
add_action('zibber_header_style', 'zibber_check_header', 10);

/**
 * header style 1 + default
 */

function zibber_header_style_1()
{
    $zibber_topbar_switch = get_theme_mod('zibber_topbar_switch', false);
    $zibber_cart_hide = get_theme_mod('zibber_cart_hide', false);
    $zibber_show_button = get_theme_mod('zibber_show_button', false);
    $zibber_show_cta = get_theme_mod('zibber_show_cta', false);
    $zibber_hamburger_hide = get_theme_mod('zibber_hamburger_hide', false);
    $zibber_show_header_search = get_theme_mod('zibber_show_header_search', false);

    $zibber_mail_id = get_theme_mod('zibber_mail_id', __('info@consulting.com', 'zibber'));
    $zibber_phone = get_theme_mod('zibber_phone', __('(+468) 254 762 443', 'zibber'));

    $zibber_header_right = get_theme_mod('zibber_header_right', false);
    $zibber_menu_col =  $zibber_header_right ? 'col-xl-6 col-lg-8 d-none d-lg-block' : 'col-xl-9 col-lg-10 d-none d-lg-block';
    $zibber_menu_right =  $zibber_header_right ? 'text-center' : 'text-right';

    $btn_text = get_theme_mod('zibber_button_text', __('Get A Quote', 'zibber'));

    $btn_link = get_theme_mod('zibber_button_link', __('#', 'zibber'));

?>

    <!-- header area start -->
    <header>
        <div class="header__area p-relative header__transparent">
            <?php if (!empty($zibber_topbar_switch)) : ?>
                <div class="header__top d-none d-md-block">
                    <div class="container">
                        <div class="row align-items-center">
                            <div class="col-xl-6 col-lg-5 col-md-4">
                                <div class="header__social">
                                    <?php zibber_header_social_profiles(); ?>
                                </div>
                            </div>
                            <div class="col-xl-6 col-lg-7 col-md-8">
                                <div class="header__info f-right">
                                    <ul>
                                        <?php if (!empty($zibber_phone)) : ?>
                                            <li>
                                                <a href="tel:<?php print esc_url($zibber_phone); ?>">
                                                    <i class="fal fa-phone-alt"></i>
                                                    <?php print esc_html($zibber_phone); ?>
                                                </a>
                                            </li>
                                        <?php endif; ?>

                                        <?php if (!empty($zibber_mail_id)) : ?>
                                            <li>
                                                <a href="mailto:<?php print esc_url($zibber_mail_id); ?>">
                                                    <i class="fal fa-envelope"></i>
                                                    <?php print esc_html($zibber_mail_id); ?>
                                                </a>
                                            </li>
                                        <?php endif; ?>

                                        <?php if (!empty($zibber_show_header_search)) : ?>
                                            <li>
                                                <a href="javascript:void(0);" class="search-toggle">
                                                    <i class="far fa-search"></i>
                                                </a>
                                            </li>
                                        <?php endif; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
            <div id="header__sticky" class="header__bottom">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-xl-3 col-lg-3 col-md-6 col-sm-6 col-6">
                            <div class="logo pt-30 pb-30">
                                <?php zibber_header_logo(); ?>
                            </div>
                            <div class="logo-gradient pt-30 pb-30">
                                <?php zibber_header_sticky_logo(); ?>
                            </div>
                        </div>
                        <div class="col-xl-9 col-lg-9 col-md-6 col-sm-6 col-6">
                            <div class="header__bottom-right d-flex justify-content-end align-items-center">
                                <div class="main-menu">
                                    <nav id="mobile-menu">
                                        <?php zibber_header_menu(); ?>
                                    </nav>
                                </div>
                                <?php if (!empty($zibber_header_right)) : ?>
                                    <?php if (!empty($btn_link)) : ?>
                                        <div class="header__btn d-none d-sm-block d-lg-none d-xl-block ml-50">
                                            <a href="<?php print esc_url($btn_link); ?>" class="z-btn z-btn-white"><?php print esc_html($btn_text); ?></a>
                                        </div>
                                    <?php endif;  ?>
                                <?php endif;  ?>
                                <div class="sidebar__menu d-lg-none">
                                    <div class="sidebar-toggle-btn" id="sidebar-toggle">
                                        <span class="line"></span>
                                        <span class="line"></span>
                                        <span class="line"></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="header__search-wrapper">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-12">
                            <form action="#">
                                <input name="s" type="text" placeholder="<?php print esc_attr('Your Keywords', 'zibber'); ?>">
                                <button type="submit"><i class="far fa-search"></i></button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
            <!-- <div class="body-overlay-2"></div> -->
        </div>
    </header>
    <!-- header area end -->

    <?php zibber_extra_info(); ?>


<?php
}

/**
 * header style 2 
 */
function zibber_header_style_2()
{
    $zibber_cart_hide = get_theme_mod('zibber_cart_hide', false);
    $zibber_show_button = get_theme_mod('zibber_show_button', false);
    $zibber_show_cta = get_theme_mod('zibber_show_cta', false);
    $zibber_hamburger_hide = get_theme_mod('zibber_hamburger_hide', false);
    $zibber_show_header_search = get_theme_mod('zibber_show_header_search', false);
    $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);

    $zibber_header_right = get_theme_mod('zibber_header_right', false);
    $btn_text = get_theme_mod('zibber_button_text', __('Get A Quote', 'zibber'));

    $btn_link = get_theme_mod('zibber_button_link',  __('#', 'zibber'));

?>

    <!-- header area start -->
    <header>
        <div class="header__area p-relative header__transparent">
            <div id="header__sticky" class="header__bottom header__bottom-2">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-xl-3 col-lg-3 col-md-6 col-sm-6 col-6">
                            <div class="logo pt-30 pb-30">
                                <?php zibber_header_logo(); ?>
                            </div>
                            <div class="logo-gradient pt-30 pb-30">
                                <?php zibber_header_sticky_logo(); ?>
                            </div>
                        </div>
                        <div class="col-xl-9 col-lg-9 col-md-6 col-sm-6 col-6">
                            <div class="header__bottom-right d-flex justify-content-end align-items-center">
                                <div class="main-menu">
                                    <nav id="mobile-menu">
                                        <?php zibber_header_menu(); ?>
                                    </nav>
                                </div>
                                <?php if (!empty($zibber_header_right)) : ?>
                                    <?php if (!empty($btn_link)) : ?>
                                        <div class="header__btn d-none d-sm-block d-xl-block ml-50">
                                            <a href="<?php print esc_url($btn_link); ?>" class="z-btn z-btn-white z-btn-white-2"><?php print esc_html($btn_text); ?></a>
                                        </div>
                                    <?php endif;  ?>
                                <?php endif;  ?>
                                <div class="sidebar__menu d-lg-none">
                                    <div class="sidebar-toggle-btn" id="sidebar-toggle">
                                        <span class="line"></span>
                                        <span class="line"></span>
                                        <span class="line"></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header area end -->

    <?php zibber_extra_info(); ?>

<?php
}

/**
 * header style 3
 */
function zibber_header_style_3()
{
    $zibber_topbar_switch = get_theme_mod('zibber_topbar_switch', false);
    $zibber_cart_hide = get_theme_mod('zibber_cart_hide', false);
    $zibber_show_button = get_theme_mod('zibber_show_button', false);
    $zibber_show_cta = get_theme_mod('zibber_show_cta', false);
    $zibber_hamburger_hide = get_theme_mod('zibber_hamburger_hide', false);
    $zibber_show_header_search = get_theme_mod('zibber_show_header_search', false);
    $btn_text_from_page = get_post_meta(get_the_ID(), 'button_text_from_page', true);
    $zibber_header_right = get_theme_mod('zibber_header_right', false);

    $btn_text = get_theme_mod('zibber_button_text', __('Get A Quote', 'zibber'));

    $btn_link = get_theme_mod('zibber_button_link', __('#', 'zibber'));


?>



    <!-- header area start -->
    <header>
        <div class="header__area p-relative header__transparent">
            <div class="header__shape p-absolute">
                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/slider/03/icon-5.png" alt="<?php print esc_attr('img', 'zibber'); ?>">
            </div>
            <div id="header__sticky" class="header__bottom header__bottom-2">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-xl-3 col-lg-3 col-md-6 col-sm-6 col-6">
                            <div class="logo-3 pt-30 pb-30">
                                <?php zibber_header_logo(); ?>
                            </div>
                        </div>
                        <div class="col-xl-9 col-lg-9 col-md-6 col-sm-6 col-6">
                            <div class="header__bottom-right d-flex justify-content-end align-items-center">
                                <div class="main-menu main-menu-3">
                                    <nav id="mobile-menu">
                                        <?php zibber_header_menu(); ?>
                                    </nav>
                                </div>
                                <?php if (!empty($zibber_header_right)) : ?>
                                    <?php if (!empty($btn_link)) : ?>
                                        <div class="header__btn d-none d-sm-block d-xl-block ml-50">
                                            <a href="<?php print esc_url($btn_link); ?>" class="z-btn z-btn-3"><?php print esc_html($btn_text); ?></a>
                                        </div>
                                    <?php endif;  ?>
                                <?php endif;  ?>
                                <div class="sidebar__menu d-lg-none">
                                    <div class="sidebar-toggle-btn sidebar-toggle-btn-3" id="sidebar-toggle">
                                        <span class="line"></span>
                                        <span class="line"></span>
                                        <span class="line"></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header area end -->

    <?php zibber_extra_info(); ?>



<?php
}

/**
 * header style 4
 */
function zibber_header_style_4()
{
    $zibber_topbar_switch = get_theme_mod('zibber_topbar_switch', false);
    $zibber_show_header_search = get_theme_mod('zibber_show_header_search', false);
    $zibber_show_lang = get_theme_mod('zibber_show_lang', false);
    $zibber_show_button = get_theme_mod('zibber_show_button', false);
    $zibber_header_right = get_theme_mod('zibber_header_right', false);

    // top left
    $zibber_mail_id = get_theme_mod('zibber_mail_id', __('info@consulting.com', 'zibber'));
    $zibber_phone = get_theme_mod('zibber_phone', __('(+468) 254 762 443', 'zibber'));

    $btn_text = get_theme_mod('zibber_button_text', __('Get A Quote', 'zibber'));

    $btn_link = get_theme_mod('zibber_button_link', __('#', 'zibber'));


?>

    <!-- header style area start -->
    <header>
        <?php if (!empty($zibber_topbar_switch)) : ?>
            <div class="header__top header__top-4 d-none d-md-block header__style-6">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-xl-6 col-lg-5 col-md-4">
                            <div class="header__social">
                                <?php zibber_header_social_profiles(); ?>
                            </div>
                        </div>
                        <div class="col-xl-6 col-lg-7 col-md-8">
                            <div class="header__info f-right">
                                <ul>
                                    <?php if (!empty($zibber_phone)) : ?>
                                        <li>
                                            <a href="tel:<?php print esc_url($zibber_phone); ?>">
                                                <i class="fal fa-phone-alt"></i>
                                                <?php print esc_html($zibber_phone); ?>
                                            </a>
                                        </li>
                                    <?php endif; ?>

                                    <?php if (!empty($zibber_mail_id)) : ?>
                                        <li>
                                            <a href="mailto:<?php print esc_url($zibber_mail_id); ?>">
                                                <i class="fal fa-envelope"></i>
                                                <?php print esc_html($zibber_mail_id); ?>
                                            </a>
                                        </li>
                                    <?php endif; ?>

                                    <?php if (!empty($zibber_show_header_search)) : ?>
                                        <li>
                                            <a href="javascript:void(0);" class="search-toggle">
                                                <i class="far fa-search"></i>
                                            </a>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div id="header__sticky" class="header__bottom">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-xl-3 col-lg-3 col-md-6 col-sm-6 col-6">
                        <div class="logo pt-30 pb-30">
                            <?php zibber_header_logo(); ?>
                        </div>
                        <div class="logo-gradient pt-30 pb-30">
                            <?php zibber_header_sticky_logo(); ?>
                        </div>
                    </div>
                    <div class="col-xl-9 col-lg-9 col-md-6 col-sm-6 col-6">
                        <div class="header__bottom-right d-flex justify-content-end align-items-center">
                            <div class="main-menu header__style-4-menu header__style-1-menu">
                                <nav id="mobile-menu">
                                    <?php zibber_header_menu(); ?>
                                </nav>
                            </div>
                            <?php if (!empty($zibber_header_right)) : ?>
                                <?php if (!empty($btn_link)) : ?>
                                    <div class="header__btn d-none d-sm-block d-lg-none d-xl-block ml-50">
                                        <a href="<?php print esc_url($btn_link); ?>" class="z-btn"><?php print esc_html($btn_text); ?></a>
                                    </div>
                                <?php endif;  ?>
                            <?php endif;  ?>
                            <div class="sidebar__menu d-lg-none">
                                <div class="sidebar-toggle-btn sidebar-toggle-btn-3" id="sidebar-toggle">
                                    <span class="line"></span>
                                    <span class="line"></span>
                                    <span class="line"></span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php zibber_search_form(); ?>
    </header>
    <!-- header style end end -->

    <?php zibber_extra_info(); ?>


<?php
}

/**
 * header style 5
 */
function zibber_header_style_5()
{
    $zibber_topbar_switch = get_theme_mod('zibber_topbar_switch', false);
    $zibber_show_header_search = get_theme_mod('zibber_show_header_search', false);
    $zibber_show_lang = get_theme_mod('zibber_show_lang', false);
    $zibber_show_button = get_theme_mod('zibber_show_button', false);
    $zibber_header_right = get_theme_mod('zibber_header_right', false);

    // top left
    $zibber_mail_id = get_theme_mod('zibber_mail_id', __('info@consulting.com', 'zibber'));
    $zibber_phone = get_theme_mod('zibber_phone', __('(+468) 254 762 443', 'zibber'));

    $btn_text = get_theme_mod('zibber_button_text', __('Get A Quote', 'zibber'));
    $btn_link = get_theme_mod('zibber_button_link',  __('#', 'zibber'));


?>

    <!-- header area start -->
    <header>
        <div class="header__area p-relative header__transparent">
            <div class="header__shape p-absolute">
                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/slider/03/icon-5.png" alt="<?php print esc_attr('Img', 'zibber'); ?>">
            </div>
            <div id="header__sticky" class="header__bottom black-bg">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-xl-3 col-lg-3 col-md-6 col-sm-6 col-6">
                            <div class="logo">
                                <?php zibber_header_logo(); ?>
                            </div>
                            <div class="logo-gradient">
                                <?php zibber_header_sticky_logo(); ?>
                            </div>
                        </div>
                        <div class="col-xl-9 col-lg-9 col-md-6 col-sm-6 col-6">
                            <div class="header__bottom-right d-flex justify-content-end align-items-center">
                                <div class="main-menu header__style-1-menu">
                                    <nav id="mobile-menu">
                                        <?php zibber_header_menu(); ?>
                                    </nav>
                                </div>
                                <?php if (!empty($zibber_header_right)) : ?>
                                    <?php if (!empty($btn_link)) : ?>
                                        <div class="header__btn d-none d-sm-block d-lg-none d-xl-block ml-50">
                                            <a href="<?php print esc_url($btn_link); ?>" class="z-btn z-btn-white z-btn-white-2 z-btn-white-3"><?php print esc_html($btn_text); ?></a>
                                        </div>
                                    <?php endif;  ?>
                                <?php endif;  ?>
                                <div class="sidebar__menu d-lg-none">
                                    <div class="sidebar-toggle-btn" id="sidebar-toggle">
                                        <span class="line"></span>
                                        <span class="line"></span>
                                        <span class="line"></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <!-- header area end -->

    <?php zibber_extra_info(); ?>

<?php
}

/**
 * header style 6 shop
 */
function zibber_header_style_6()
{
    $zibber_topbar_switch = get_theme_mod('zibber_topbar_switch', false);
    $zibber_show_header_search = get_theme_mod('zibber_show_header_search', false);
    $zibber_show_lang = get_theme_mod('zibber_show_lang', false);
    $zibber_show_button = get_theme_mod('zibber_show_button', false);
    $zibber_header_right = get_theme_mod('zibber_header_right', false);

    // top left
    $zibber_mail_id = get_theme_mod('zibber_mail_id', __('info@consulting.com', 'zibber'));
    $zibber_phone = get_theme_mod('zibber_phone', __('(+468) 254 762 443', 'zibber'));

    // acc btn
    $acc_btn_text = get_theme_mod('zibber_acc_button_text', __('Login or Register', 'zibber'));
    $acc_btn_link = get_theme_mod('zibber_acc_button_link', __('#', 'zibber'));


?>

    <!-- header style area start -->
    <header class="position-relative header__style-6">
        <?php if (!empty($zibber_topbar_switch)) : ?>
            <div class="header__top header__top-4 d-none d-md-block">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-xl-6 col-lg-5 col-md-4">
                            <div class="header__social">
                                <?php zibber_header_social_profiles(); ?>
                            </div>
                        </div>
                        <div class="col-xl-6 col-lg-7 col-md-8">
                            <div class="header__info f-right">
                                <ul>
                                    <?php if (!empty($zibber_phone)) : ?>
                                        <li>
                                            <a href="tel:<?php print esc_url($zibber_phone); ?>">
                                                <i class="fal fa-phone-alt"></i>
                                                <?php print esc_html($zibber_phone); ?>
                                            </a>
                                        </li>
                                    <?php endif; ?>

                                    <?php if (!empty($zibber_mail_id)) : ?>
                                        <li>
                                            <a href="mailto:<?php print esc_url($zibber_mail_id); ?>">
                                                <i class="fal fa-envelope"></i>
                                                <?php print esc_html($zibber_mail_id); ?>
                                            </a>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div id="header__sticky" class="header__bottom">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-xl-2 col-lg-3 col-md-6 col-sm-4 col-6">
                        <div class="logo pt-30 pb-30">
                            <?php zibber_header_logo(); ?>
                        </div>
                        <div class="logo-gradient pt-30 pb-30">
                            <?php zibber_header_sticky_logo(); ?>
                        </div>
                    </div>
                    <div class="col-xl-10 col-lg-9 col-md-6 col-sm-8 col-6">
                        <div class="header__bottom-right d-flex justify-content-end justify-content-lg-between align-items-center">
                            <div class="main-menu header__style-4-menu header__style-1-menu">
                                <nav id="mobile-menu">
                                    <?php zibber_header_menu(); ?>
                                </nav>
                            </div>

                            <?php if (!empty($zibber_header_right)) : ?>
                                <div class="z-header-right">
                                    <?php if (!empty($acc_btn_link)) : ?>
                                        <div class="header__btn_acc d-none d-sm-block ml-50">
                                            <a href="<?php print esc_url($acc_btn_link); ?>" class="z-btn-text"><?php print esc_html($acc_btn_text); ?></a>
                                        </div>
                                    <?php endif;  ?>

                                    <div class="header-icon">
                                        <?php if (!empty($zibber_show_header_search)) : ?>
                                            <a href="javascript:void(0);" class="search-toggle"><i class="fal fa-search"></i></a>
                                        <?php endif;  ?>

                                        <?php if (ZIBBER_WOOCOMMERCE_ACTIVED) : ?>
                                            <a class="bild-cart" href="<?php echo wc_get_cart_url(); ?>"><i class="fal fa-shopping-cart"></i><span><?php echo esc_html(WC()->cart->cart_contents_count); ?></span> </a>
                                        <?php endif;  ?>
                                    </div>
                                </div>

                            <?php endif;  ?>



                            <div class="sidebar__menu d-lg-none">
                                <div class="sidebar-toggle-btn sidebar-toggle-btn-3" id="sidebar-toggle">
                                    <span class="line"></span>
                                    <span class="line"></span>
                                    <span class="line"></span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php zibber_search_form(); ?>
    </header>
    <!-- header style end end -->

    <?php zibber_extra_info(); ?>


<?php
}


/** 
 * [zibber_extra_info description]
 * @return [type] [description]
 */
function zibber_extra_info()
{
    $zibber_extra_info_logo   = get_theme_mod('zibber_extra_info_logo', get_template_directory_uri() . '/assets/img/logo/logo.png');

    // about title
    $zibber_extra_about_text     = get_theme_mod('zibber_extra_about_text', __('We must explain to you how all seds this mistakens idea off denouncing pleasures and praising pain was born and I will give you a completed accounts of the system and expound.', 'zibber'));
    $zibber_extra_button     = get_theme_mod('zibber_extra_button', __('Contact Us', 'zibber'));
    $zibber_extra_button_url     = get_theme_mod('zibber_extra_button_url', __('#', 'zibber'));

    // address
    $zibber_extra_address     = get_theme_mod('zibber_extra_address', __('Ave 14th Street, Mirpur 210, San Franciso, USA 3296.', 'zibber'));

    // phone 
    $zibber_extra_phone   = get_theme_mod('zibber_extra_phone', __('+0989 7876 9865 9', 'zibber'));

    // email 
    $zibber_extra_email  = get_theme_mod('zibber_extra_email', __('info@example.com', 'zibber'));

?>

    <!-- sidebar area start -->
    <section class="sidebar__area">
        <div class="sidebar__wrapper">
            <div class="sidebar__close">
                <button class="sidebar__close-btn" id="sidebar__close-btn">
                    <span><i class="fal fa-times"></i></span>
                    <span><?php print esc_html__('close', 'zibber'); ?></span>
                </button>
            </div>
            <div class="sidebar__tab">
                <ul class="nav nav-tabs" id="sidebar-tab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="menu-tab" data-toggle="tab" href="#menu" role="tab" aria-controls="menu" aria-selected="true"><?php print esc_html__('menu', 'zibber'); ?></a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="info-tab" data-toggle="tab" href="#info" role="tab" aria-controls="info" aria-selected="false"><?php print esc_html__('info', 'zibber'); ?></a>
                    </li>
                </ul>
            </div>
            <div class="sidebar__content">
                <div class="tab-content" id="sidebar-tab-content">
                    <div class="tab-pane fade show active" id="menu" role="tabpanel" aria-labelledby="menu-tab">
                        <?php if (!empty($zibber_extra_info_logo)) : ?>
                            <div class="logo mb-40">
                                <a href="<?php print esc_url(home_url('/')); ?>">
                                    <img src="<?php print esc_url($zibber_extra_info_logo); ?>" alt="<?php print esc_attr('Logo', 'zibber'); ?>">
                                </a>
                            </div>
                        <?php endif; ?>
                        <div class="mobile-menu"></div>
                    </div>
                    <div class="tab-pane fade" id="info" role="tabpanel" aria-labelledby="info-tab">
                        <div class="sidebar__info">
                            <?php if (!empty($zibber_extra_info_logo)) : ?>
                                <div class="logo mb-40">
                                    <a href="<?php print esc_url(home_url('/')); ?>">
                                        <img src="<?php print esc_url($zibber_extra_info_logo); ?>" alt="<?php print esc_attr('Logo', 'zibber'); ?>">
                                    </a>
                                </div>
                            <?php endif; ?>

                            <?php if (!empty($zibber_extra_about_text)) : ?>
                                <p><?php print esc_html($zibber_extra_about_text); ?></p>
                            <?php endif; ?>

                            <?php if (!empty($zibber_extra_button)) : ?>
                                <a href="<?php print esc_url($zibber_extra_button_url); ?>" class="z-btn z-btn-white"><?php print esc_html($zibber_extra_button); ?></a>
                            <?php endif; ?>

                            <div class="sidebar__search">
                                <form action="#">
                                    <input type="text" placeholder="<?php print esc_attr('Your Keywords', 'zibber'); ?>">
                                    <button type="submit"><i class="fal fa-search"></i></button>
                                </form>
                            </div>
                            <div class="sidebar__contact mt-30">
                                <ul>
                                    <?php if (!empty($zibber_extra_address)) : ?>
                                        <li>
                                            <div class="icon">
                                                <i class="fal fa-map-marker-alt"></i>
                                            </div>
                                            <div class="text">
                                                <span><?php print esc_html($zibber_extra_address); ?></span>
                                            </div>
                                        </li>
                                    <?php endif; ?>
                                    <?php if (!empty($zibber_extra_email)) : ?>
                                        <li>
                                            <div class="icon">
                                                <i class="fal fa-envelope"></i>
                                            </div>
                                            <div class="text ">
                                                <span><a href="mailto:<?php print esc_url($zibber_extra_email); ?>"><?php print esc_html($zibber_extra_email); ?></a></span>
                                            </div>
                                        </li>
                                    <?php endif; ?>
                                    <?php if (!empty($zibber_extra_phone)) : ?>
                                        <li>
                                            <div class="icon">
                                                <i class="fas fa-phone-alt"></i>
                                            </div>
                                            <div class="text">
                                                <span><a href="tel:<?php print esc_url($zibber_extra_phone); ?>"><?php print esc_html($zibber_extra_phone); ?></a></span>
                                            </div>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <div class="body-overlay"></div>
    <!-- sidebar area end -->


    <?php }

/** 
 * [zibber_header_lang description]
 * @return [type] [description]
 */
function zibber_header_lang_defualt()
{
    $zibber_header_lang            = get_theme_mod('zibber_header_lang', false);
    if ($zibber_header_lang) : ?>

        <ul>
            <li><a href="#0" class="lang__btn"><?php print esc_html__('EN', 'zibber'); ?> <i class="ti-arrow-down"></i></a>
                <?php do_action('zibber_language'); ?>
            </li>
        </ul>

    <?php endif; ?>
<?php
}


/** 
 * [zibber_language_list description]
 * @return [type] [description]
 */
function _zibber_language($mar)
{
    return $mar;
}
function zibber_language_list()
{

    $mar = '';
    $languages = apply_filters('wpml_active_languages', NULL, 'orderby=id&order=desc');
    if (!empty($languages)) {
        $mar = '<ul>';
        foreach ($languages as $lan) {
            $active = $lan['active'] == 1 ? 'active' : '';
            $mar .= '<li class="' . $active . '"><a href="' . $lan['url'] . '">' . $lan['translated_name'] . '</a></li>';
        }
        $mar .= '</ul>';
    } else {
        //remove this code when send themeforest reviewer team
        $mar .= '<ul>';
        $mar .= '<li><a href="#">' . esc_html__('USA', 'zibber') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('UK', 'zibber') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('CA', 'zibber') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('AU', 'zibber') . '</a></li>';
        $mar .= ' </ul>';
    }
    print _zibber_language($mar);
}
add_action('zibber_language', 'zibber_language_list');

// favicon logo
function zibber_favicon_logo_func()
{
    $zibber_favicon = get_template_directory_uri() . '/assets/img/logo/favicon.png';
    $zibber_favicon_url = get_theme_mod('favicon_url', $zibber_favicon);
?>

    <link rel="shortcut icon" type="image/x-icon" href="<?php print esc_url($zibber_favicon_url); ?>">

<?php
}
add_action('wp_head', 'zibber_favicon_logo_func');

// header logo
function zibber_header_logo()
{
?>
    <?php
    $zibber_logo_on = function_exists('get_field') ? get_field('is_enable_sec_logo') : NULL;
    $zibber_logo = get_template_directory_uri() . '/assets/img/logo/logo.png';
    $zibber_logo_black = get_template_directory_uri() . '/assets/img/logo/logo-gradient.png';

    $zibber_site_logo = get_theme_mod('logo', $zibber_logo);
    $zibber_secondary_logo = get_theme_mod('seconday_logo', $zibber_logo_black);
    ?>

    <?php
    if (has_custom_logo()) {
        the_custom_logo();
    } else {

        if (!empty($zibber_logo_on)) { ?>
            <a class="standard-logo" href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($zibber_secondary_logo); ?>" alt="<?php print esc_attr('logo', 'zibber'); ?>" />
            </a>
        <?php
        } else { ?>
            <a class="standard-logo-white" href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($zibber_site_logo); ?>" alt="<?php print esc_attr('logo', 'zibber'); ?>" />
            </a>
    <?php
        }
    }
    ?>
<?php
}

// header logo
function zibber_header_sticky_logo()
{
?>
    <?php
    $zibber_logo = get_template_directory_uri() . '/assets/img/logo/logo-gradient.png';

    $zibber_site_logo = get_theme_mod('logo_sticky', $zibber_logo);
    ?>

    <?php
    if (has_custom_logo()) {
        the_custom_logo();
    } else { ?>

        <a class="standard-logo-white" href="<?php print esc_url(home_url('/')); ?>">
            <img src="<?php print esc_url($zibber_site_logo); ?>" alt="<?php print esc_attr('logo', 'zibber'); ?>" />
        </a>
    <?php

    }
    ?>
<?php
}



/** 
 * [zibber_header_social_profiles description]
 * @return [type] [description]
 */
function zibber_header_social_profiles()
{
    $zibber_topbar_fb_url             = get_theme_mod('zibber_topbar_fb_url', __('#', 'zibber'));
    $zibber_topbar_twitter_url       = get_theme_mod('zibber_topbar_twitter_url', __('#', 'zibber'));
    $zibber_topbar_instagram_url      = get_theme_mod('zibber_topbar_instagram_url', __('#', 'zibber'));
    $zibber_topbar_linkedin_url      = get_theme_mod('zibber_topbar_linkedin_url', __('#', 'zibber'));
    $zibber_topbar_youtube_url        = get_theme_mod('zibber_topbar_youtube_url', __('#', 'zibber'));
?>
    <ul>
        <?php if (!empty($zibber_topbar_fb_url)) : ?>
            <li><a href="<?php print esc_url($zibber_topbar_fb_url); ?>"><i class="fab fa-facebook-f"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($zibber_topbar_twitter_url)) : ?>
            <li><a href="<?php print esc_url($zibber_topbar_twitter_url); ?>"><i class="fab fa-twitter"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($zibber_topbar_instagram_url)) : ?>
            <li><a href="<?php print esc_url($zibber_topbar_instagram_url); ?>"><i class="fab fa-instagram"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($zibber_topbar_linkedin_url)) : ?>
            <li><a href="<?php print esc_url($zibber_topbar_linkedin_url); ?>"><i class="fab fa-linkedin"></i></a></li>
        <?php endif; ?>

        <?php if (!empty($zibber_topbar_youtube_url)) : ?>
            <li><a href="<?php print esc_url($zibber_topbar_youtube_url); ?>"><i class="fab fa-youtube"></i></a></li>
        <?php endif; ?>
    </ul>
<?php
}


function zibber_footer_social_profiles()
{
    $zibber_footer_fb_url             = get_theme_mod('zibber_footer_fb_url', __('#', 'zibber'));
    $zibber_footer_twitter_url       = get_theme_mod('zibber_footer_twitter_url', __('#', 'zibber'));
    $zibber_footer_instagram_url      = get_theme_mod('zibber_footer_instagram_url', __('#', 'zibber'));
    $zibber_footer_linkedin_url      = get_theme_mod('zibber_footer_linkedin_url', __('#', 'zibber'));
    $zibber_footer_youtube_url        = get_theme_mod('zibber_footer_youtube_url', __('#', 'zibber'));
?>

    <ul>
        <?php if (!empty($zibber_footer_fb_url)) : ?>
            <li>
                <a href="<?php print esc_url($zibber_footer_fb_url); ?>">
                    <i class="fab fa-facebook-f"></i>
                    <i class="fab fa-facebook-f"></i>
                </a>
            </li>
        <?php endif; ?>

        <?php if (!empty($zibber_footer_twitter_url)) : ?>
            <li>
                <a href="<?php print esc_url($zibber_footer_twitter_url); ?>">
                    <i class="fab fa-twitter"></i>
                    <i class="fab fa-twitter"></i>
                </a>
            </li>
        <?php endif; ?>

        <?php if (!empty($zibber_footer_instagram_url)) : ?>
            <li>
                <a href="<?php print esc_url($zibber_footer_instagram_url); ?>">
                    <i class="fab fa-instagram"></i>
                    <i class="fab fa-instagram"></i>
                </a>
            </li>
        <?php endif; ?>

        <?php if (!empty($zibber_footer_linkedin_url)) : ?>
            <li>
                <a href="<?php print esc_url($zibber_footer_linkedin_url); ?>">
                    <i class="fab fa-linkedin"></i>
                    <i class="fab fa-linkedin"></i>
                </a>
            </li>
        <?php endif; ?>

        <?php if (!empty($zibber_footer_youtube_url)) : ?>
            <li>
                <a href="<?php print esc_url($zibber_footer_youtube_url); ?>">
                    <i class="fab fa-youtube"></i>
                    <i class="fab fa-youtube"></i>
                </a>
            </li>
        <?php endif; ?>
    </ul>
<?php
}


/** 
 * [zibber_header_menu description]
 * @return [type] [description]
 */
function zibber_header_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location'    => 'main-menu',
        'menu_class'        => '',
        'container'         => '',
        'fallback_cb'       => 'Navwalker_Class::fallback',
        'walker'            => new Navwalker_Class
    ));
    ?>
<?php
}

/**
 * [zibber_header_menu description]
 * @return [type] [description]
 */
function zibber_mobile_menu()
{ ?>
    <?php
    $zibber_menu = wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class'     => '',
        'container'      => '',
        'menu_id'        => 'mobile-menu-active',
        'echo'           => false
    ));

    $zibber_menu = str_replace("menu-item-has-children", "menu-item-has-children has-children", $zibber_menu);
    echo wp_kses_post($zibber_menu);
    ?>
<?php
}

/** 
 * [zibber_footer_menu description]
 * @return [type] [description]
 */
function zibber_footer_menu()
{
    wp_nav_menu(array(
        'theme_location'    => 'footer-menu',
        'menu_class'        => 'm-0',
        'container'         => '',
        'fallback_cb'       => 'Navwalker_Class::fallback',
        'walker'            => new Navwalker_Class
    ));
}

/**
 *
 * zibber footer
 */
add_action('zibber_footer_style', 'zibber_check_footer', 10);

function zibber_check_footer()
{
    $zibber_footer_style = function_exists('get_field') ? get_field('footer_style') : NULL;
    $zibber_default_footer_style = get_theme_mod('choose_default_footer', 'footer-style-1');


    if ($zibber_footer_style == 'footer-style-1') {
        zibber_footer_style_1();
    } elseif ($zibber_footer_style == 'footer-style-2') {
        zibber_footer_style_2();
    } elseif ($zibber_footer_style == 'footer-style-3') {
        zibber_footer_style_3();
    } elseif ($zibber_footer_style == 'footer-style-4') {
        zibber_footer_style_4();
    } elseif ($zibber_footer_style == 'footer-style-5') {
        zibber_footer_style_5();
    } else {

        /** default footer style **/
        if ($zibber_default_footer_style == 'footer-style-2') {
            zibber_footer_style_2();
        } elseif ($zibber_default_footer_style == 'footer-style-3') {
            zibber_footer_style_3();
        } elseif ($zibber_default_footer_style == 'footer-style-4') {
            zibber_footer_style_4();
        } elseif ($zibber_default_footer_style == 'footer-style-5') {
            zibber_footer_style_5();
        } else {
            zibber_footer_style_1();
        }
    }
}

/**
 * footer  style_defaut
 */
function zibber_footer_style_1()
{

    $footer_bg_img = get_theme_mod('zibber_footer_bg');
    $zibber_footer_logo = get_theme_mod('zibber_footer_logo');
    $zibber_copyright_center = $zibber_footer_logo ? 'col-lg-4 offset-lg-4 col-md-6 text-right' : 'col-lg-12 text-center';
    $zibber_footer_bg_url_from_page = function_exists('get_field') ? get_field('zibber_footer_bg') : '';
    $zibber_footer_bg_color_from_page = function_exists('get_field') ? get_field('zibber_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('zibber_footer_bg_color');

    // bg image
    $bg_img = !empty($zibber_footer_bg_url_from_page['url']) ? $zibber_footer_bg_url_from_page['url'] : $footer_bg_img;

    // bg color
    $bg_color = !empty($zibber_footer_bg_color_from_page) ? $zibber_footer_bg_color_from_page : $footer_bg_color;

    // footer_columns
    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-5';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-md-7';
            $footer_class[3] = 'col-xl-4 col-lg-6';
            break;
        case '4':
            $footer_class[1] = 'col-xl-3 col-lg-3 col-md-4 col-sm-6 footer-col-1 ';
            $footer_class[2] = 'col-xl-3 col-lg-3 col-md-4 col-sm-6 footer-col-2 pl-50';
            $footer_class[3] = 'col-xl-3 col-lg-3 col-md-4 col-sm-6 footer-col-3 pl-20';
            $footer_class[4] = 'col-xl-3 col-lg-3 col-md-4 col-sm-6 footer-col-4 pl-20';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer>
        <div class="footer__area one footer-default black-bg" data-bg-color="<?php print esc_attr($bg_color); ?>" data-background="<?php print esc_url($bg_img); ?>">
            <?php if (is_active_sidebar('footer-1') or is_active_sidebar('footer-2') or is_active_sidebar('footer-3') or is_active_sidebar('footer-4')) : ?>
                <div class="footer__top pt-100 pb-45">
                    <div class="container">
                        <div class="row">
                            <?php
                            if ($footer_columns < 4) {
                                print '<div class="col-xl-3 col-lg-3 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-1');
                                print '</div>';

                                print '<div class="col-xl-3 col-lg-3 col-md-4 col-sm-6 offset-xl-1">';
                                dynamic_sidebar('footer-2');
                                print '</div>';

                                print '<div class="col-xl-3 col-lg-3 col-md-4 col-sm-6 offset-xl-1">';
                                dynamic_sidebar('footer-3');
                                print '</div>';

                                print '<div class="col-xl-3 col-lg-3 col-md-4 col-sm-6 offset-xl-1">';
                                dynamic_sidebar('footer-4');
                                print '</div>';
                            } else {
                                for ($num = 1; $num <= $footer_columns; $num++) {
                                    if (!is_active_sidebar('footer-' . $num)) continue;
                                    print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                    dynamic_sidebar('footer-' . $num);
                                    print '</div>';
                                }
                            }

                            ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
            <div class="footer__copyright footer__copyright-2">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-xl-12 text-center">
                            <div class="footer__copyright-text footer__copyright-text-2">
                                <p><?php print zibber_copyright_text(); ?></p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>
<?php
}

/**
 * footer  style 2
 */
function zibber_footer_style_2()
{
    $footer_bg_img = get_theme_mod('zibber_footer_bg');
    $zibber_footer_social = get_theme_mod('zibber_footer_social');
    $zibber_copyright_center = $zibber_footer_social ? 'col-xl-6 col-lg-6 col-md-6' : 'col-lg-12 text-center';
    $zibber_footer_bg_url_from_page = function_exists('get_field') ? get_field('zibber_footer_bg') : '';
    $zibber_footer_bg_color_from_page = function_exists('get_field') ? get_field('zibber_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('zibber_footer_bg_color');

    // bg image
    $bg_img = !empty($zibber_footer_bg_url_from_page['url']) ? $zibber_footer_bg_url_from_page['url'] : $footer_bg_img;
    // bg color
    $bg_color = !empty($zibber_footer_bg_color_from_page) ? $zibber_footer_bg_color_from_page : $footer_bg_color;

    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-2-' . $num)) {
            $footer_columns++;
        }
    }



    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-5';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-md-7';
            $footer_class[3] = 'col-xl-4 col-lg-6';
            break;
        case '4':
            $footer_class[1] = 'col-xl-2 col-lg-2 col-md-4 col-sm-6';
            $footer_class[2] = 'col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6';
            $footer_class[3] = 'col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6';
            $footer_class[4] = 'col-xl-3 offset-xl-1 col-lg-3 offset-lg-1 col-md-4 col-sm-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer class="footer-style-2">
        <div class="footer__area two grey-bg" data-bg-color="<?php print esc_attr($bg_color); ?>" data-background="<?php print esc_url($bg_img); ?>">
            <?php if (is_active_sidebar('footer-2-1') or is_active_sidebar('footer-2-2') or is_active_sidebar('footer-2-3') or is_active_sidebar('footer-2-4')) : ?>
                <div class="footer__top pt-100 pb-45">
                    <div class="container">
                        <div class="row">
                            <?php
                            if ($footer_columns < 4) {
                                print '<div class="col-xl-2 col-lg-2 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-2-1');
                                print '</div>';

                                print '<div class="col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-2-2');
                                print '</div>';

                                print '<div class="col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-2-3');
                                print '</div>';

                                print '<div class="col-xl-3 offset-xl-1 col-lg-3 offset-lg-1 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-2-4');
                                print '</div>';
                            } else {
                                for ($num = 1; $num <= $footer_columns; $num++) {
                                    if (!is_active_sidebar('footer-2-' . $num)) continue;
                                    print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                    dynamic_sidebar('footer-2-' . $num);
                                    print '</div>';
                                }
                            }

                            ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
            <div class="footer__copyright">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="<?php print esc_attr($zibber_copyright_center); ?>">
                            <div class="footer__copyright-text">
                                <p><?php print zibber_copyright_text(); ?></p>
                            </div>
                        </div>
                        <?php if (!empty($zibber_footer_social)) : ?>
                            <div class="col-xl-6 col-lg-6 col-md-6">
                                <div class="footer__social theme-social f-right">
                                    <?php zibber_footer_social_profiles(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </footer>

<?php
}


/**
 * footer 3
 */
function zibber_footer_style_3()
{

    $footer_bg_img = get_theme_mod('zibber_footer_bg');
    $zibber_footer_bg_url_from_page = function_exists('get_field') ? get_field('zibber_footer_bg') : '';
    $zibber_footer_bg_color_from_page = function_exists('get_field') ? get_field('zibber_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('zibber_footer_bg_color');

    // bg image
    $bg_img = !empty($zibber_footer_bg_url_from_page['url']) ? $zibber_footer_bg_url_from_page['url'] : $footer_bg_img;

    // bg color
    $bg_color = !empty($zibber_footer_bg_color_from_page) ? $zibber_footer_bg_color_from_page : $footer_bg_color;

    $footer_columns = 0;

    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets + 1; $num++) {
        if (is_active_sidebar('footer-3-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-12';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-sm-6 col-6';
            $footer_class[3] = 'col-xl-4 col-lg-6';
        case '4':
            $footer_class[1] = 'col-xl-3 col-lg-3 col-md-4 col-sm-6';
            $footer_class[2] = 'col-xl-2 col-lg-3 col-md-4 col-sm-6 offset-xl-1';
            $footer_class[3] = 'col-xl-2 col-lg-3 col-md-4 col-sm-6 offset-xl-1';
            $footer_class[4] = 'col-xl-3 col-lg-3 col-md-5 col-sm-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer>
        <div class="footer__area three grey-bg" data-bg-color="<?php print esc_attr($bg_color); ?>" data-background="<?php print esc_url($bg_img); ?>">
            <?php if (is_active_sidebar('footer-3-1') or is_active_sidebar('footer-3-2') or is_active_sidebar('footer-3-3') or is_active_sidebar('footer-3-4')) : ?>
                <div class="footer__top pb-45 pt-100">
                    <div class="container">
                        <div class="row">
                            <?php

                            if ($footer_columns < 4) {
                                print '<div class="col-xl-3 col-lg-3 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-3-1');
                                print '</div>';

                                print '<div class="col-xl-2 col-lg-3 col-md-4 col-sm-6 offset-xl-1">';
                                dynamic_sidebar('footer-3-2');
                                print '</div>';

                                print '<div class="col-xl-2 col-lg-3 col-md-4 col-sm-6 offset-xl-1">';
                                dynamic_sidebar('footer-3-3');
                                print '</div>';

                                print '<div class="col-xl-3 col-lg-3 col-md-5 col-sm-6">';
                                dynamic_sidebar('footer-3-4');
                                print '</div>';
                            } else {
                                for ($num = 1; $num <= $footer_columns; $num++) {
                                    if (!is_active_sidebar('footer-3-' . $num)) continue;
                                    print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                    dynamic_sidebar('footer-3-' . $num);
                                    print '</div>';
                                }
                            }
                            ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
            <div class="footer__copyright">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-12">
                            <div class="footer__copyright-text text-center">
                                <p><?php print zibber_copyright_text(); ?></p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>

<?php
}

/**
 * footer 4
 */
function zibber_footer_style_4()
{

    $footer_bg_img = get_theme_mod('zibber_footer_bg');
    $zibber_footer_bg_url_from_page = function_exists('get_field') ? get_field('zibber_footer_bg') : '';
    $zibber_footer_bg_color_from_page = function_exists('get_field') ? get_field('zibber_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('zibber_footer_bg_color');

    // bg image
    $bg_img = !empty($zibber_footer_bg_url_from_page['url']) ? $zibber_footer_bg_url_from_page['url'] : $footer_bg_img;

    // bg color
    $bg_color = !empty($zibber_footer_bg_color_from_page) ? $zibber_footer_bg_color_from_page : $footer_bg_color;

    $footer_columns = 0;

    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets + 1; $num++) {
        if (is_active_sidebar('footer-3-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-12';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-sm-6 col-6';
            $footer_class[3] = 'col-xl-4 col-lg-6';
        case '4':
            $footer_class[1] = 'col-xl-3 col-lg-3 col-md-4 col-sm-6 pr-0';
            $footer_class[2] = 'col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6';
            $footer_class[3] = 'col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6';
            $footer_class[4] = 'col-xl-3  col-lg-3 col-md-4 col-sm-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer>
        <div class="footer__area four grey-bg" data-bg-color="<?php print esc_attr($bg_color); ?>" data-background="<?php print esc_url($bg_img); ?>">
            <?php if (is_active_sidebar('footer-4-1') or is_active_sidebar('footer-4-2') or is_active_sidebar('footer-4-3') or is_active_sidebar('footer-4-4')) : ?>
                <div class="footer__top pb-45 pt-100">
                    <div class="container">
                        <div class="row">
                            <?php
                            if ($footer_columns < 4) {
                                print '<div class="col-xl-3 col-lg-3 col-md-4 col-sm-6 pr-0">';
                                dynamic_sidebar('footer-3-1');
                                print '</div>';

                                print '<div class="col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-3-2');
                                print '</div>';

                                print '<div class="col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-3-3');
                                print '</div>';

                                print '<div class="col-xl-3  col-lg-3 col-md-4 col-sm-6">';
                                dynamic_sidebar('footer-3-4');
                                print '</div>';
                            } else {
                                for ($num = 1; $num <= $footer_columns; $num++) {
                                    if (!is_active_sidebar('footer-4-' . $num)) continue;
                                    print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                    dynamic_sidebar('footer-4-' . $num);
                                    print '</div>';
                                }
                            }
                            ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
            <div class="footer__copyright-3">
                <div class="container">
                    <div class="footer__copyright-inner">
                        <div class="row align-items-center">
                            <div class="col-xl-12">
                                <div class="footer__copyright-text text-center">
                                    <p><?php print zibber_copyright_text(); ?></p>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>

<?php
}

/**
 * footer 5
 */
function zibber_footer_style_5()
{

    $footer_bg_img = get_theme_mod('zibber_footer_bg');
    $footer_email_label = get_theme_mod('footer_email_label', 'E-Mail ');
    $footer_email = get_theme_mod('footer_email', 'zibber@example.com');
    $footer_phone_label = get_theme_mod('footer_phone_label', 'Phone ');
    $footer_phone = get_theme_mod('footer_phone', '+8801234567890');
    $zibber_footer_social = get_theme_mod('zibber_footer_social');
    $zibber_footer_bg_url_from_page = function_exists('get_field') ? get_field('zibber_footer_bg') : '';
    $zibber_footer_bg_color_from_page = function_exists('get_field') ? get_field('zibber_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('zibber_footer_bg_color');

    // bg image
    $bg_img = !empty($zibber_footer_bg_url_from_page['url']) ? $zibber_footer_bg_url_from_page['url'] : $footer_bg_img;

    // bg color
    $bg_color = !empty($zibber_footer_bg_color_from_page) ? $zibber_footer_bg_color_from_page : $footer_bg_color;

    $footer_columns = 0;

    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets + 1; $num++) {
        if (is_active_sidebar('footer-3-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-12';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-sm-6 col-6';
            $footer_class[3] = 'col-xl-4 col-lg-6';
        case '4':
            $footer_class[1] = 'col-xl-3 col-lg-3 col-md-4 col-sm-6 pr-0';
            $footer_class[2] = 'col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6';
            $footer_class[3] = 'col-xl-2 offset-xl-1 col-lg-2 offset-lg-1 col-md-4 col-sm-6';
            $footer_class[4] = 'col-xl-3  col-lg-3 col-md-4 col-sm-6';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

?>

    <footer>
        <div class="footer__area footer-black-bg footer-style-5 pb-40 pt-100" data-bg-color="<?php print esc_attr($bg_color); ?>" data-background="<?php print esc_url($bg_img); ?>">

            <div class="footer__top">
                <div class="container">
                    <div class="foo-contact-wrapper">
                        <?php if (!empty($footer_email)) : ?>
                            <div class="left-side mb-30">
                                <div class="email-wrapper contact-info">
                                    <h6 class="contact-upper-title"> <span><?php echo esc_html($footer_email_label); ?> </span></h6>
                                    <h3 class="contact-title"> <a href="mailto:<?php echo esc_url($footer_email); ?>"> <?php echo esc_html($footer_email); ?> </a></h3>
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php if (!empty($footer_phone)) : ?>
                            <div class="right-side mb-30">
                                <div class="email-wrapper contact-info">
                                    <h6 class="contact-upper-title"> <span> <?php echo esc_html($footer_phone_label); ?> </span></h6>
                                    <h3 class="contact-title"> <a href="tell:<?php echo esc_url($footer_phone); ?>"> <?php echo esc_html($footer_phone); ?> </a></h3>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            <div class="footer__copyright-3">
                <div class="container">
                    <div class="footer__copyright-inner">
                        <div class="row align-items-center">
                            <div class="col-lg-6 col-md-7">
                                <div class="footer__copyright-text">
                                    <p><?php print zibber_copyright_text(); ?></p>
                                </div>
                            </div>
                            <?php if (!empty($zibber_footer_social)) : ?>
                                <div class="col-xl-6 col-lg-6 col-md-5">
                                    <div class="footer__social theme-social text-right">
                                        <?php zibber_footer_social_profiles(); ?>
                                    </div>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </footer>

    <?php
}


// zibber_copyright_text
function zibber_copyright_text()
{
    print get_theme_mod('zibber_copyright', __('Copyright ©2021 Theme_Pure. All Rights Reserved', 'zibber'));
}


/** 
 * [zibber_breadcrumb_func description]
 * @return [type] [description]
 */
function zibber_breadcrumb_func()
{

    $breadcrumb_class = '';
    $breadcrumb_show = 1;

    if (is_front_page() && is_home()) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog', 'zibber'));
        $breadcrumb_class = 'home_front_page';
    } elseif (is_front_page()) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog', 'zibber'));
        $breadcrumb_show = 0;
    } elseif (is_home()) {
        if (get_option('page_for_posts')) {
            $title = get_the_title(get_option('page_for_posts'));
        }
    } elseif (is_single() && 'post' == get_post_type()) {
        $title = get_the_title();
    } elseif (is_single() && 'product' == get_post_type()) {
        $title = get_the_title();
    } elseif (is_single() && 'bdevs-services' == get_post_type()) {
        $title = get_the_title();
    } elseif (is_single() && 'bdevs-doctor' == get_post_type()) {
        $title = get_theme_mod('breadcrumb_doctor_details', __('Doctor Details', 'zibber'));
    } elseif (is_single() && 'bdevs-cases' == get_post_type()) {
        $title = get_the_title();
    } elseif (is_search()) {
        $title = esc_html__('Search Results for : ', 'zibber') . get_search_query();
    } elseif (is_404()) {
        $title = esc_html__('Page not Found', 'zibber');
    } elseif (function_exists('is_woocommerce') && is_woocommerce()) {
        $title = get_theme_mod('breadcrumb_shop', __('Shop', 'zibber'));
    } elseif (is_archive()) {
        $title = get_the_archive_title();
    } else {
        $title = get_the_title();
    }

    $_id = get_the_ID();

    if (is_single() && 'product' == get_post_type()) {
        // $_id = $post->ID;
    } elseif (function_exists("is_shop") and is_shop()) {
        $_id = wc_get_page_id('shop');
    } elseif (is_home() && get_option('page_for_posts')) {
        $_id = get_option('page_for_posts');
    }

    $is_breadcrumb = function_exists('get_field') ? get_field('is_it_invisible_breadcrumb', $_id) : '';
    if (!empty($_GET['s'])) {
        $is_breadcrumb = null;
    }


    if (empty($is_breadcrumb) && $breadcrumb_show == 1) {

        $bg_img_from_page = function_exists('get_field') ? get_field('breadcrumb_background_image') : '';
        $hide_bg_img = function_exists('get_field') ? get_field('hide_breadcrumb_background_image') : '';
        $back_title = function_exists('get_field') ? get_field('breadcrumb_back_title') : '';

        // get_theme_mod
        $bg_img = get_theme_mod('breadcrumb_bg_img');


        if ($hide_bg_img) {
            $bg_img = '';
        } else {
            $bg_img = !empty($bg_img_from_page) ? $bg_img_from_page['url'] : $bg_img;
        } ?>

        <?php
        $breadcrumb_switch = get_theme_mod('breadcrumb_switch', true);
        ?>

        <?php if (!empty($breadcrumb_switch)) : ?>
            <section class="page__title p-relative d-flex align-items-center fix <?php print esc_attr($breadcrumb_class); ?>" data-background="<?php print esc_attr($bg_img); ?>">
                <div class="slider__shape">
                    <img class="shape triangle" src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/slider/triangle.png" alt="<?php print esc_attr('img', 'zibber'); ?>">
                    <img class="shape dotted-square" src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/slider/dotted-square.png" alt="<?php print esc_attr('img', 'zibber'); ?>">
                    <img class="shape solid-square" src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/slider/solid-square.png" alt="<?php print esc_attr('img', 'zibber'); ?>">
                    <img class="shape circle-2" src="<?php echo get_template_directory_uri(); ?>/assets/img/icon/slider/circle.png" alt="<?php print esc_attr('img', 'zibber'); ?>">
                </div>
                <div class="container">
                    <div class="row">
                        <div class="col-xl-12">
                            <div class="page__title-content mt-100">
                                <h2><?php echo wp_kses_post($title); ?></h2>
                                <div class="page_title__bread-crumb">
                                    <?php zibber_breadcrumb_callback(); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
        <?php endif; ?>

    <?php
    }
}
add_action('zibber_before_main_content', 'zibber_breadcrumb_func');


function zibber_breadcrumb_callback()
{
    $args = array(
        'show_browse'   => false,
        'post_taxonomy' => array('product' => 'product_cat')
    );
    $breadcrumb = new Breadcrumb_Class($args);

    return $breadcrumb->trail();
}


// gru_search_form
function zibber_search_form()
{ ?>
    <!-- Modal Search -->

    <div class="header__search-wrapper">
        <div class="container">
            <div class="row">
                <div class="col-xl-12">
                    <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                        <input type="search" name="s" class="main-search-input" value="<?php print esc_attr(get_search_query()) ?>" placeholder="<?php print esc_attr('Your Keyword...', 'zibber'); ?>">
                        <button type="submit"><i class="far fa-search"></i></button>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <!-- <div class="body-overlay-2"></div> -->

<?php
}

// add_action('zibber_before_main_content', 'zibber_search_form');

/**
 *
 * pagination
 */
if (!function_exists('zibber_pagination')) {

    function _zibber_pagi_callback($pagination)
    {
        return $pagination;
    }

    //page navegation
    function zibber_pagination($prev, $next, $pages, $args)
    {
        global $wp_query, $wp_rewrite;
        $menu = '';
        $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

        if ($pages == '') {
            global $wp_query;
            $pages = $wp_query->max_num_pages;

            if (!$pages)
                $pages = 1;
        }

        $pagination = array(
            'base' => add_query_arg('paged', '%#%'),
            'format' => '',
            'total' => $pages,
            'current' => $current,
            'prev_text' => $prev,
            'next_text' => $next,
            'type' => 'array'
        );

        //rewrite permalinks
        if ($wp_rewrite->using_permalinks())
            $pagination['base'] = user_trailingslashit(trailingslashit(remove_query_arg('s', get_pagenum_link(1))) . 'page/%#%/', 'paged');

        if (!empty($wp_query->query_vars['s']))
            $pagination['add_args'] = array('s' => get_query_var('s'));

        $pagi = '';
        if (paginate_links($pagination) != '') {
            $paginations = paginate_links($pagination);
            $pagi .= '<ul>';
            foreach ($paginations as $key => $pg) {
                $pagi .= '<li>' . $pg . '</li>';
            }
            $pagi .= '</ul>';
        }

        print _zibber_pagi_callback($pagi);
    }
}




// header top bg color
function zibber_breadcrumb_bg_color()
{
    $color_code = get_theme_mod('zibber_breadcrumb_bg_color', '#690ed0  ');
    $color_code2 = get_theme_mod('zibber_breadcrumb_bg_color_2', '#170da2 ');
    wp_enqueue_style('zibber-breadcrumb-bg', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".page__title::before{ background: linear-gradient(60deg, " . $color_code2 . " 0%, " . $color_code . " 100%) }";

        wp_add_inline_style('zibber-breadcrumb-bg', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'zibber_breadcrumb_bg_color');

// breadcrumb-spacing top
function zibber_breadcrumb_spacing()
{
    $padding_px = get_theme_mod('zibber_breadcrumb_spacing', '160px');
    wp_enqueue_style('zibber-custom', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
    if ($padding_px != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacing{ padding-top: " . $padding_px . "}";

        wp_add_inline_style('zibber-breadcrumb-top-spacing', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'zibber_breadcrumb_spacing');

// breadcrumb-spacing bottom
function zibber_breadcrumb_bottom_spacing()
{
    $padding_px = get_theme_mod('zibber_breadcrumb_bottom_spacing', '160px');
    wp_enqueue_style('zibber-custom', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
    if ($padding_px != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacing{ padding-bottom: " . $padding_px . "}";

        wp_add_inline_style('zibber-breadcrumb-bottom-spacing', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'zibber_breadcrumb_bottom_spacing');


// scrollup
function zibber_scrollup_switch()
{
    $scrollup_switch = get_theme_mod('zibber_scrollup_switch', false);
    wp_enqueue_style('zibber-custom', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
    if ($scrollup_switch) {
        $custom_css = '';
        $custom_css .= "#scrollUp{ display: none !important;}";

        wp_add_inline_style('zibber-scrollup-switch', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'zibber_scrollup_switch');


// theme color
// function zibber_custom_color()
// {
//     $color_code = get_theme_mod('zibber_color_option', '#4636ff');
//     wp_enqueue_style('zibber-custom-color', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
//     if ($color_code != '') {
//         $custom_css = '';
//         $custom_css .= ".main-menu ul li ul.submenu li a::before, .about__list ul li:hover span i, .wpcf7-submit.z-btn, .footer__subscribe button, .expart__nav .nav-link.active, .header__bottom.sticky .header__btn a, .z-btn-border:hover, .project__item:hover .project__no h5, .services__action::after, .basic-pagination ul li span.current, 
//             .sidebar__widget-title h4::after, .tagcloud a:hover, blockquote cite::before, .blog__tag a:hover, 
//             .footer__widget ul li a::before, .team__details-social ul li a:hover, .product-action a:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .basic-pagination ul li a:hover, .blog__btn .z-btn, .z-btn,.price__item a.price-btn:hover { background-color: " . $color_code . "}";

//         $custom_css .= ".about__list ul li:hover span, .about__list ul li span i, .services__content h3:hover a, .wpcf7-submit.z-btn:hover, .price__tab .nav-tabs .nav-item .nav-link.active, .header__bottom.sticky .main-menu ul li:hover > a, .hero__content span, .services__nav .nav-link i, .project__no h5, .faq__accordion .btn-link, .faq__accordion .btn-link::before, .services__link ul li a::after, .services__link ul li a:hover, .services__action a i, .services__action a:hover, .services__list ul li::after, .portfolio__menu button.active, .portfolio__content h4 a:hover, .link-btn-2.link-btn-3:hover, .link-btn-2:hover, .pro-title h6:hover, .pro-desc-tab .nav-link.active, .sidebar__widget-content .search button, .rc-text h6 a:hover, 
//             .sidebar__widget ul li a::after, .sidebar__widget ul li a:hover, .post-meta span i, .post-meta a:hover, .blog__content-2 h3 a:hover, blockquote::before, .logged-in-as a:hover, .price__item a.price-btn, .portfolio__menu button:hover, .section__title span, .footer__copyright-text p a:hover, .main-menu ul li ul.submenu li:hover > a, .footer__widget ul li a:hover, .faq__wrapper .btn-link::before,  .theme-color a, .team__details-contact ul li .icon i, .team__details-contact ul li .icon i, .author-icon a:hover, .features__icon-2 i { color: " . $color_code . "}";

//         $custom_css .= ".wpcf7-submit.z-btn, .contact__form input:focus, .contact__form textarea:focus, .header__bottom.sticky .header__btn a, .z-btn-border:hover, .services__form input:focus, .tagcloud a:hover, .blog__tag a:hover, .post-input input:focus, .post-input textarea:focus, .price__item, .main-menu ul li ul.submenu li a::before, .main-menu ul li ul.submenu, .blog__btn .z-btn, .z-btn{ border-color: " . $color_code . "}";
//         wp_add_inline_style('zibber-custom-color', $custom_css);
//     }
// }
// add_action('wp_enqueue_scripts', 'zibber_custom_color');



// color
function zibber_all_color()
{
    $zb_primary_color = get_theme_mod('zb_primary_color', '#4636ff');
    $zb_secondary_color = get_theme_mod('zb_secondary_color', '#8923FF');
    $zb_body_color = get_theme_mod('zb_body_color', '#686777');
    $zb_heading_color = get_theme_mod('zb_heading_color', '#1f1841');
    $zb_black_color = get_theme_mod('zb_black_color', '#000');
    $zb_white_color = get_theme_mod('zb_white_color', '#fff');

    wp_enqueue_style('zibber-custom', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());

    $custom_css = '';
    $custom_css .= ":root{
            --zb-primary: " . $zb_primary_color . ";
            --zb-secondary: " . $zb_secondary_color . ";
            --zb-body: " . $zb_body_color . ";
            --zb-heading: " . $zb_heading_color . ";
            --zb-black: " . $zb_black_color . ";
            --zb-white: " . $zb_white_color . ";
        }";

    wp_add_inline_style('zibber-custom', $custom_css);
}
add_action('wp_enqueue_scripts', 'zibber_all_color');



// Logo size 
function zibber_logo_size()
{
    $logo_size = get_theme_mod('zibber_logo_size', '105px');
    wp_enqueue_style('zibber-custom', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
    if ($logo_size != '') {
        $custom_css = '';
        $custom_css .= ".logo img { width: " . $logo_size . "}";
        wp_add_inline_style('zibber-custom', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'zibber_logo_size');


// body font
function zibber_body_font()
{
    $zibber_body_font = get_theme_mod('zibber_body_font', "'Lato', sans-serif");
    wp_enqueue_style('zibber-body-font', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
    if ($zibber_body_font != '') {
        $custom_css = '';
        $custom_css .= "body{ font-family: " . $zibber_body_font . "}";
        wp_add_inline_style('zibber-body-font', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'zibber_body_font');

// Heading font
function zibber_heading_font()
{
    $zibber_heading_font = get_theme_mod('zibber_heading_font', "'Frank Ruhl Libre', sans-serif");
    wp_enqueue_style('zibber-heading-font', ZIBBER_THEME_CSS_DIR . 'zibber-custom.css', array());
    if ($zibber_heading_font != '') {
        $custom_css = '';
        $custom_css .= "h1,h2,h3,h4,h5,h6{ font-family: " . $zibber_heading_font . "}";
        wp_add_inline_style('zibber-heading-font', $custom_css);
    }
}
add_action('wp_enqueue_scripts', 'zibber_heading_font');

// zibber_kses_intermediate
function zibber_kses_intermediate($string = '')
{
    return wp_kses($string, zibber_get_allowed_html_tags('intermediate'));
}

function zibber_get_allowed_html_tags($level = 'basic')
{
    $allowed_html = [
        'b' => [],
        'i' => [],
        'u' => [],
        'em' => [],
        'br' => [],
        'abbr' => [
            'title' => [],
        ],
        'span' => [
            'class' => [],
        ],
        'strong' => [],
        'a' => [
            'href' => [],
            'title' => [],
            'class' => [],
            'id' => []
        ]
    ];

    return $allowed_html;
}
